# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`ntpd`](#ntpd): Set up ntpd in either standalone or server mode
* [`ntpd::ntpdate`](#ntpd--ntpdate): Manage the setup of ``ntpdate``

### Defined types

* [`ntpd::allow`](#ntpd--allow): Allow access to this server from a particular address or netmask

### Data types

* [`Ntpd::Discard`](#Ntpd--Discard): ntp ``discard`` options
* [`Ntpd::Restrict`](#Ntpd--Restrict): ntp ``restrict`` options
* [`Ntpd::Servers`](#Ntpd--Servers): ntp servers can be an array of servers   or a hash where the keys are servers and the values are an array of options

## Classes

### <a name="ntpd"></a>`ntpd`

Set up ntpd in either standalone or server mode

* **See also**
  * ntp.conf(5)

#### Parameters

The following parameters are available in the `ntpd` class:

* [`ntpd_options`](#-ntpd--ntpd_options)
* [`servers`](#-ntpd--servers)
* [`stratum`](#-ntpd--stratum)
* [`logconfig`](#-ntpd--logconfig)
* [`broadcastdelay`](#-ntpd--broadcastdelay)
* [`default_options`](#-ntpd--default_options)
* [`default_restrict`](#-ntpd--default_restrict)
* [`default_restrict6`](#-ntpd--default_restrict6)
* [`admin_hosts`](#-ntpd--admin_hosts)
* [`admin_hosts6`](#-ntpd--admin_hosts6)
* [`discard`](#-ntpd--discard)
* [`disable_monitor`](#-ntpd--disable_monitor)
* [`manage_ntpdate`](#-ntpd--manage_ntpdate)
* [`trusted_nets`](#-ntpd--trusted_nets)
* [`default_restrict_rules`](#-ntpd--default_restrict_rules)
* [`firewall`](#-ntpd--firewall)
* [`ntpdate_servers`](#-ntpd--ntpdate_servers)
* [`ntpdate_sync_hwclock`](#-ntpd--ntpdate_sync_hwclock)
* [`ntpdate_retry`](#-ntpd--ntpdate_retry)
* [`ntpdate_options`](#-ntpd--ntpdate_options)
* [`use_local_clock`](#-ntpd--use_local_clock)
* [`auditd`](#-ntpd--auditd)
* [`package_ensure`](#-ntpd--package_ensure)
* [`extra_content`](#-ntpd--extra_content)
* [`config_content`](#-ntpd--config_content)

##### <a name="-ntpd--ntpd_options"></a>`ntpd_options`

Data type: `String[1]`

Options for the ntp daemon, put into `/etc/sysconfig/ntpd`

Default value: `'-g'`

##### <a name="-ntpd--servers"></a>`servers`

Data type: `Ntpd::Servers`

An array of servers or a Hash of server/option pairs providing details
for the NTP servers that this system should synchronize with

* **Example**

  ```
  servers => {
    'time.local.net' => ['iburst','minpoll 4', 'prefer'],
    # This one will just use $default_options
    'time.other.net' => []
  }
  ```

Default value: `simplib::lookup('simp_options::ntp::servers', { 'default_value' => simplib::lookup('simp_options::ntpd::servers', { 'default_value' => {} }) })`

##### <a name="-ntpd--stratum"></a>`stratum`

Data type: `Integer[0]`

The stratum for this system

* This only comes into play if no external servers are defined and the
  stratum has to be fudged

Default value: `2`

##### <a name="-ntpd--logconfig"></a>`logconfig`

Data type: `Array[String[1]]`

A list of options for refining the system log output

Default value: `['=syncall','+clockall']`

##### <a name="-ntpd--broadcastdelay"></a>`broadcastdelay`

Data type: `Numeric`

Default calibration delay

Default value: `0.004`

##### <a name="-ntpd--default_options"></a>`default_options`

Data type: `Array[String[1]]`

The default options that will be added to all servers

* Set to an empty array to disable

Default value: `['minpoll 4','maxpoll 4','iburst']`

##### <a name="-ntpd--default_restrict"></a>`default_restrict`

Data type: `Array[Ntpd::Restrict]`

The default IPv4 ``restrict`` options

Default value: `['kod', 'nomodify', 'notrap', 'nopeer', 'noquery']`

##### <a name="-ntpd--default_restrict6"></a>`default_restrict6`

Data type: `Array[Ntpd::Restrict]`

The default IPv6 ``restrict`` options

Default value: `$default_restrict`

##### <a name="-ntpd--admin_hosts"></a>`admin_hosts`

Data type: `Array[Simplib::IP::V4]`

Hosts that are allowed unrestricted access via IPv4

Default value: `['127.0.0.1']`

##### <a name="-ntpd--admin_hosts6"></a>`admin_hosts6`

Data type: `Array[Simplib::IP::V6]`

Hosts that are allowed unrestricted access via IPv6

Default value: `['::1']`

##### <a name="-ntpd--discard"></a>`discard`

Data type: `Optional[Ntpd::Discard]`

An optional has that can be used to set the average,minimum and
monitor options for ``discard``

Default value: `undef`

##### <a name="-ntpd--disable_monitor"></a>`disable_monitor`

Data type: `Boolean`

Disable the monitoring facility to prevent amplification attacks using
``ntpdc monlist`` command when default restrict does not include the
``noquery`` flag

* See CVE-2013-5211 for details

Default value: `true`

##### <a name="-ntpd--manage_ntpdate"></a>`manage_ntpdate`

Data type: `Boolean`

Manage ntpdate settings

Default value: `true`

##### <a name="-ntpd--trusted_nets"></a>`trusted_nets`

Data type: `Optional[Simplib::Netlist]`

Setting this to an Array of networks/hostnames that you trust for
communication will enable a default ``ntpd::alow`` entry so that remote
systems can query this system for time.

Default value: `undef`

##### <a name="-ntpd--default_restrict_rules"></a>`default_restrict_rules`

Data type: `Optional[Array[Ntpd::Restrict]]`

Set to an Array of ``restrict`` rules of your choosing

* Has no effect if ``$trusted_nets`` is not set

Default value: `undef`

##### <a name="-ntpd--firewall"></a>`firewall`

Data type: `Boolean`

Enable management of the firewall in relation to inbound communication

* Has no effect if ``$trusted_nets`` is not set

Default value: `simplib::lookup('simp_options::firewall', { 'default_value' => false})`

##### <a name="-ntpd--ntpdate_servers"></a>`ntpdate_servers`

Data type: `Ntpd::Servers`

NTP servers that are used in the ntpdate script at startup

Default value: `$servers`

##### <a name="-ntpd--ntpdate_sync_hwclock"></a>`ntpdate_sync_hwclock`

Data type: `Boolean`

Set to `true` to sync hw clock after successful ntpdate. Set in
`/etc/sysconfig/ntpdate`

Default value: `true`

##### <a name="-ntpd--ntpdate_retry"></a>`ntpdate_retry`

Data type: `Integer[0]`

Number of retries before giving up. Set in `/etc/sysconfig/ntpdate`

Default value: `2`

##### <a name="-ntpd--ntpdate_options"></a>`ntpdate_options`

Data type: `String[1]`

Options for ntpdate. Set in `/etc/sysconfig/ntpdate`

Default value: `'-p 2'`

##### <a name="-ntpd--use_local_clock"></a>`use_local_clock`

Data type: `Boolean`

Set the server and fudge list to the local clock in ntp.conf

Default value: `true`

##### <a name="-ntpd--auditd"></a>`auditd`

Data type: `Boolean`

Enable auditd monitoring of the ntp configuration files

* This probably isn't needed in most cases since Puppet controls these
  files, but some systems require it

Default value: `simplib::lookup('simp_options::auditd', { 'default_value' => false})`

##### <a name="-ntpd--package_ensure"></a>`package_ensure`

Data type: `String`

`ensure` parameter for the `ntp` package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-ntpd--extra_content"></a>`extra_content`

Data type: `Optional[String[1]]`

An unvalidated String that will be appended to the configuration file

Default value: `undef`

##### <a name="-ntpd--config_content"></a>`config_content`

Data type: `Optional[String[1]]`

The entire content of the configuration file. ALL OTHER ntpd CONFIGURATION
OPTIONS WILL BE IGNORED.

* NOTE: Calls to ``ntpd::allow`` will still add ``restrict`` lines to the
  configuration.

Default value: `undef`

### <a name="ntpd--ntpdate"></a>`ntpd::ntpdate`

Manage the setup of ``ntpdate``

## Defined types

### <a name="ntpd--allow"></a>`ntpd::allow`

Allow access to this server from a particular address or netmask

#### Parameters

The following parameters are available in the `ntpd::allow` defined type:

* [`rules`](#-ntpd--allow--rules)
* [`trusted_nets`](#-ntpd--allow--trusted_nets)
* [`firewall`](#-ntpd--allow--firewall)

##### <a name="-ntpd--allow--rules"></a>`rules`

Data type:

```puppet
Optional[Variant[
    String[1],Array[Ntpd::Restrict]
  ]]
```

A standard ``ntpd.conf`` restrict rule (``notrust``, etc...)

Default value: `undef`

##### <a name="-ntpd--allow--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

Networks and Hosts to allow

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1', '::1'] })`

##### <a name="-ntpd--allow--firewall"></a>`firewall`

Data type: `Boolean`

If enabled, allow connections from `trusted_nets`

Default value: `simplib::lookup('simp_options::firewall', { 'default_value' => false})`

## Data types

### <a name="Ntpd--Discard"></a>`Ntpd::Discard`

ntp ``discard`` options

Alias of

```puppet
Struct[{
  Optional[average] => Integer[0],
  Optional[minimum] => Integer[0],
  Optional[monitor] => Integer[1]
}]
```

### <a name="Ntpd--Restrict"></a>`Ntpd::Restrict`

ntp ``restrict`` options

Alias of `Enum['flake', 'ignore', 'kod', 'limited', 'lowpriotrap', 'mssntp', 'nomodify', 'non-ntpport', 'nopeer', 'noquery', 'noserve', 'notrap', 'notrust', 'ntpport', 'version']`

### <a name="Ntpd--Servers"></a>`Ntpd::Servers`

ntp servers can be an array of servers
  or
a hash where the keys are servers and the values are an array of options

Alias of `Variant[Array[String], Hash[String, Array[String]]]`

